#include <sys/types.h>
#include <time.h>

/* Shared library capable of fooling some programs into thinking the
 * current time and date are different from the real system time and
 * date.
 *
 * compile:  make
 * test:     LD_PRELOAD=./timefix.so date
 *
 * Replace 'date' with the program you want to fool.  If the program
 * requires the correct date to function, you are out of luck.
 *
 * If your program calls gettimeofday() to find out the date, you will
 * have to override that function instead of time().
 *
 * Written by:  Chris Studholme
 * Last Update: 12-Jan-1999
 * Copyright:   GPL (http://www.fsf.org/copyleft/gpl.html)
 */     


time_t time(time_t *tloc) {
  time_t TIME;
  struct tm timestruct;
  timestruct.tm_sec  = 0;        /* seconds (0-59) */
  timestruct.tm_min  = 0;        /* minutes (0-59) */
  timestruct.tm_hour = 0;        /* hours (0-23) */
  timestruct.tm_mday = 1;        /* day of the month (1-31) */
  timestruct.tm_mon  = 0;        /* month (0-11) */
  timestruct.tm_year = 99;       /* year (year-1900) */
  timestruct.tm_wday=0;          /* day of the week (ignored) */
  timestruct.tm_yday=0;          /* day in the year (ignored) */
  timestruct.tm_isdst=-1;        /* daylight saving time (unknown) */
  TIME = mktime(&timestruct);
  return tloc!=0 ? *tloc=TIME : TIME;
}
